Tutorials — species 0.1.2 documentation

# Tutorials

This page contains a list of tutorials which highlight some of the functionalities of species. These examples are also available as Jupyter notebook. Some of tutorials are still work in progress and more examples will be added in the future. Feel free to contact Tomas Stolker if you have questions regarding a specific science case (see About section). Please create an issue on Github if you encounter any problems with the tutorials.

- Flux and magnitude conversion
- Synthetic photometry
- Spectral library
- Color-magnitude diagram: broadband filters
- Color-magnitude diagram: narrowband filters
- Atmospheric models
- Comparison of data and model
- Photometric calibration: fitting a stellar spectrum
- Fitting photometry with model spectra

Important

A flux calibrated spectrum of Vega is used for the conversion between flux density and magnitude. The magnitude of Vega is set to 0.03 mag for all filters (see also Stolker et al. 2020).